@@ -13,6 +13,12 @@ CORE_USER_OPEN_ID_API_PATH = '/api/core_i/get_openid/'
 CORE_GO_MEMBER_INFO_API_PATH = '/api/core_go/member'
 CORE_GO_I_USER_INFO = '/api/core_go_i/users?user_id={}'
 
+# *******************************************************
+# 以下部分：涉及 sparrow_lanyue 服务接口
+# *******************************************************
+# 批量获取用户信息
+LANYUE_I_USER_INFO = '/api/sparrow_lanyue/account_i/bulk_user/'
+
 
 # *******************************************************
 # 以下部分：涉及 sparrow_product 服务接口
