@@ -1264,7 +1264,7 @@ class VLines(BaseModelTimeAndDeleted):
         app_label = 'sparrow_aftersale'
 
 
-class VLinePayment(models.Model):
+class VLinePayment(BaseModelTimeAndDeleted):
     ''' 虚拟订单的支付方式 '''
 
     CouponSourceChoices = (
@@ -1310,7 +1310,7 @@ class VLinePayment(models.Model):
         app_label = 'sparrow_aftersale'
 
 
-class VLinePromotion(models.Model):
+class VLinePromotion(BaseModelTimeAndDeleted):
     ''' 虚拟订单的活动 '''
 
     id = models.CharField("id", primary_key=True, max_length=40, default=get_uuid4_hex)
@@ -1345,11 +1345,17 @@ class VLinePromotion(models.Model):
     summary = models.CharField("Promotion Summary",
                                max_length=256, blank=True)
 
+    # 绑卡礼需求-2022.05.16
+    # 只有赠品活动才有此值（全部 common| 会员绑卡礼 auth_gift）
+    # 当gift_type==auth_gift时，就算是订单享受了绑卡礼
+    # 退货时, 如果原始订单中的绑卡礼活动消失, 则要发送消息解绑已送绑卡礼
+    gift_type = models.CharField("赠品类型", max_length=20, blank=True, null=True)
+
     class Meta:
         app_label = 'sparrow_aftersale'
 
 
-class VlinesOnlyRefund(models.Model):
+class VlinesOnlyRefund(BaseModelTimeAndDeleted):
     ''' 虚拟订单行对应的该行商品的总仅退差价额 '''
     CouponSourceChoices = (
         (CouponSource.ONLINE, '线上'),
@@ -1366,14 +1372,14 @@ class VlinesOnlyRefund(models.Model):
     amount = models.DecimalField("Amount", decimal_places=2, max_digits=12)
     coupon_id = models.CharField('Coupon ID', max_length=50, blank=True, null=True, db_index=True)
     coupon_number = models.CharField('Coupon Number', max_length=64, blank=True, null=True, db_index=True)
-    coupon_source = models.CharField('来源', max_length=64, default=CouponSource.IN_STORE, choices=CouponSourceChoices)
+    coupon_source = models.CharField('来源', max_length=64, null=True, choices=CouponSourceChoices)
     pay_step_type = models.CharField("Pay Step Type", max_length=24, choices=PayStepType.PAY_STEP_TYPE_CHOICES, default=PayStepType.ONCE, db_index=True)
 
     class Meta:
         app_label = 'sparrow_aftersale'
 
 
-class AfsVlinesOnlyRefundPoint(models.Model):
+class AfsVlinesOnlyRefundPoint(BaseModelTimeAndDeleted):
     ''' 由仅退差价后在各行扣除的积分 '''
     id = models.CharField("id", primary_key=True, max_length=40, default=get_uuid4_hex)
     vline_id = models.PositiveIntegerField('VLine ID', blank=True, null=True, db_index=True)
@@ -1388,7 +1394,7 @@ class AfsVlinesOnlyRefundPoint(models.Model):
         app_label = 'sparrow_aftersale'
 
 
-class AfsVersionSuite(models.Model):
+class AfsVersionSuite(BaseModelTimeAndDeleted):
     afsid_v2 = models.PositiveIntegerField("AfsID_V2", primary_key=True)
     afsid_v3 = models.PositiveIntegerField("AfsID_v3")
 
@@ -1396,7 +1402,7 @@ class AfsVersionSuite(models.Model):
         app_label = 'sparrow_aftersale'
 
 
-class AfsVlinesPointsCharge(models.Model):
+class AfsVlinesPointsCharge(BaseModelTimeAndDeleted):
     ''' V3版本售后需要在用户积分不够扣的情况下, 提供给客服编辑扣除积分的空间 '''
     aftersale_id = models.PositiveIntegerField("AfsID_V2", primary_key=True)
     # 由退货重算生成的原始积分
